# Welcome to SHRY

**SHRY** (**S**uite for **H**igh-th**r**oughput generation of models with atomic substitutions implemented by p**y**thon) is a tool for generating unique ordered structures corresponding to a given disordered structure.

![SHRY logo](_static/logo.jpg)

The following features of **SHRY** are highlighted:

- Use of Canonical Augmentation to handle atomic substitution
- Efficient enumeration of valid substitution patterns
- Support for supercell generation
- Interfaces with Pymatgen structures


```{toctree}
:hidden:
install
examples
notes/technical_notes
api_reference_cli
api_reference_mod/modules
citation
reference
changelog
```

## License

MIT license.

## Developers

- Kosuke Nakano, National Institute for Materials Science
- Genki Imam Prayogo, AdvanceSoft Corporation

## Acknowledgements

**SHRY** development is currently supported by:

- National Institute for Materials Science (NIMS).
